Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewContainer ¶
NewContainer sets up and runs a docker container for the given image.
The container is cleaned up when the test ends.
func NewFactory ¶
NewFactory generates a sweet compatible DepFactory that spins up Redis test containers of the given image.
Types ¶
type Container ¶
type Container interface {
Request() testcontainers.ContainerRequest
Close(ctx context.Context, container testcontainers.Container) error
}
Click to show internal directories.
Click to hide internal directories.